@@ -1,5 +1,5 @@
 /* GNOME DB library
- * Copyright (C) 1999-2001 The Free Software Foundation
+ * Copyright (C) 1999-2002 The GNOME Foundation.
  *
  * AUTHORS:
  *	Rodrigo Moya <rodrigo@gnome-db.org>
@@ -38,7 +38,7 @@
 #include "gnome-db-shortcut.h"
 #include "gnome-db-summary.h"
 
-#define PARENT_TYPE BONOBO_X_OBJECT_TYPE
+#define PARENT_TYPE BONOBO_OBJECT_TYPE
 
 struct _GnomeDbShellPrivate {
 	GtkWidget *window;
@@ -292,17 +292,21 @@ static void
 verb_HelpAbout (BonoboUIComponent *uic, void *user_data, const char *path)
 {
 	static const gchar *authors[] = {
-                "Michael Lausch <michael@lausch.at>\n",
-                "Rodrigo Moya <rodrigo@gnome-db.org>\n",
-		"Stephan Heinze <stephan.heinze@xcom.de>\n",
-		"Vivien Malerba <malerba@gnome-db.org>\n",
-		"Nick Gorham <nick@lurcher.org>\n",
-		"Chris Wiegand <cwiegand@urgentmail.com>\n",
-		"Akira TAGOH <tagoh@gnome-db.org>\n",
-		"Carlos Perell Marn <carlos@gnome-db.org>\n",
-		"Holger Thon <holger.thon@gnome-db.org>\n",
-		"Reinhard Mller <reinhard@gnue.org>\n",
-		"Gerhard Dieringer <gdieringer@compuserve.com>\n",
+                "Michael Lausch <michael@lausch.at>",
+                "Rodrigo Moya <rodrigo@gnome-db.org>",
+		"Stephan Heinze <stephan.heinze@xcom.de>",
+		"Vivien Malerba <malerba@gnome-db.org>",
+		"Nick Gorham <nick@lurcher.org>",
+		"Chris Wiegand <cwiegand@urgentmail.com>",
+		"Akira TAGOH <tagoh@gnome-db.org>",
+		/* If your encoding allows it, use oacute (U00F3) for the 'o'
+		 * of 'Perello' and use iacute (U00ED) for the 'i' of 'Marin' */
+		N_("Carlos Perello Marin <carlos@gnome-db.org>"),
+		"Holger Thon <holger.thon@gnome-db.org>",
+		/* If your encoding allows it, use udiaeresis for the 'u'
+		 * of 'Muller' */
+		N_("Reinhard Muller <reinhard@gnue.org>"),
+		"Gerhard Dieringer <gdieringer@compuserve.com>",
                 NULL
         };
 
@@ -313,6 +317,7 @@ verb_HelpAbout (BonoboUIComponent *uic, void *user_data, const char *path)
                                   _("GNOME Database front-end"),
                                   authors, NULL, NULL, NULL);
         gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
 }
 
 static void
@@ -394,7 +399,7 @@ impl_UIShell_notifyConnectionOpened (PortableServer_Servant servant,
 				     const CORBA_char *username,
 				     const CORBA_char *password)
 {
-	GnomeDbShell *shell = (GnomeDbShell *) bonobo_x_object (servant);
+	GnomeDbShell *shell = (GnomeDbShell *) bonobo_object (servant);
 
 	g_return_if_fail (GNOME_DB_IS_SHELL (shell));
 }
@@ -405,7 +410,7 @@ impl_UIShell_notifyConnectionClosed (PortableServer_Servant servant,
 				     const CORBA_char *username,
 				     const CORBA_char *password)
 {
-	GnomeDbShell *shell = (GnomeDbShell *) bonobo_x_object (servant);
+	GnomeDbShell *shell = (GnomeDbShell *) bonobo_object (servant);
 
 	g_return_if_fail (GNOME_DB_IS_SHELL (shell));
 }
@@ -455,20 +460,19 @@ gnome_db_shell_finalize (GObject *object)
 	/* free memory */
 	gda_config_remove_listener (shell->priv->config_listener_id);
 
-	g_list_foreach (shell->priv->activated_components, (GFunc) g_object_unref, NULL);
+	gnome_db_window_close (GNOME_DB_WINDOW (shell->priv->window));
+	shell->priv->window = NULL;
+
 	g_list_free (shell->priv->activated_components);
 	shell->priv->activated_components = NULL;
 
-	gnome_db_window_close (GNOME_DB_WINDOW (gnome_db_shell_get_window (shell)));
-	shell->priv->window = NULL;
-
 	g_free (shell->priv);
 	shell->priv = NULL;
 
 	parent_class->finalize (object);
 }
 
-BONOBO_X_TYPE_FUNC_FULL (GnomeDbShell,
+BONOBO_TYPE_FUNC_FULL (GnomeDbShell,
 			 GNOME_Database_UIShell,
 			 PARENT_TYPE,
 			 gnome_db_shell)
